@@ -39,11 +39,6 @@ class ELISALIB_EXPORT ElisaApplication : public QObject
 
     Q_OBJECT
 
-    Q_PROPERTY(DataTypes::EntryDataList arguments
-               READ arguments
-               WRITE setArguments
-               NOTIFY argumentsChanged)
-
     Q_PROPERTY(ElisaUtils::PlayListEntryType embeddedView
                READ embeddedView
                NOTIFY embeddedViewChanged)
@@ -90,6 +85,10 @@ class ELISALIB_EXPORT ElisaApplication : public QObject
                READ showSystemTrayIcon
                NOTIFY showSystemTrayIconChanged)
 
+    Q_PROPERTY(bool useFavoriteStyleRatings
+               READ useFavoriteStyleRatings
+               NOTIFY useFavoriteStyleRatingsChanged)
+
     Q_PROPERTY(QAbstractItemModel* colorSchemesModel
                READ colorSchemesModel
                CONSTANT)
@@ -104,6 +103,7 @@ public:
     ~ElisaApplication() override;
 
     Q_INVOKABLE QAction* action(const QString& name);
+    Q_INVOKABLE const QString actionShortcut(QAction *action) const;
 
     Q_INVOKABLE QString iconName(const QIcon& icon);
 
@@ -113,8 +113,6 @@ public:
 
     bool eventFilter(QObject *object, QEvent *event) override;
 
-    [[nodiscard]] const DataTypes::EntryDataList &arguments() const;
-
     [[nodiscard]] MusicListenersManager *musicManager() const;
 
     [[nodiscard]] MediaPlayList *mediaPlayList() const;
@@ -135,14 +133,14 @@ public:
 
     [[nodiscard]] bool showSystemTrayIcon() const;
 
+    [[nodiscard]] bool useFavoriteStyleRatings() const;
+
     [[nodiscard]] ElisaUtils::PlayListEntryType embeddedView() const;
 
     int initialViewIndex() const;
 
 Q_SIGNALS:
 
-    void argumentsChanged();
-
     void musicManagerChanged();
 
     void mediaPlayListChanged();
@@ -169,6 +167,8 @@ Q_SIGNALS:
 
     void showSystemTrayIconChanged();
 
+    void useFavoriteStyleRatingsChanged();
+
     void commitDataRequest(QSessionManager &manager);
 
     void embeddedViewChanged();
@@ -187,13 +187,14 @@ public Q_SLOTS:
 
     void configureElisa();
 
-    void setArguments(const DataTypes::EntryDataList &newArguments);
+    void openFiles(const QList<QUrl> &files);
+    void openFiles(const QList<QUrl> &files, const QString &workingDirectory);
 
     void activateActionRequested(const QString &actionName, const QVariant &parameter);
 
     void activateRequested(const QStringList &arguments, const QString &workingDirectory);
 
-    void openRequested(const QList< QUrl > &uris);
+    void openRequested(const QList<QUrl> &uris);
 
     void initialize();
 
