@@ -7,7 +7,6 @@
 #include "config-upnp-qt.h"
 #include "elisa-version.h"
 
-#include "elisaarguments.h"
 #include "elisaapplication.h"
 #include "elisa_settings.h"
 
@@ -15,17 +14,17 @@
 
 //#define QT_QML_DEBUG
 
-#if defined KF5Declarative_FOUND && KF5Declarative_FOUND
+#if KF5Declarative_FOUND
 #include <KDeclarative/KDeclarative>
 #include <KQuickAddons/QtQuickSettings>
 #endif
 
-#include <KI18n/KLocalizedString>
-#include <KI18n/KLocalizedContext>
+#include <KLocalizedString>
+#include <KLocalizedContext>
 
-#include <KCoreAddons/KAboutData>
+#include <KAboutData>
 
-#if defined KF5Crash_FOUND && KF5Crash_FOUND
+#if KF5Crash_FOUND
 #include <KCrash>
 #endif
 
@@ -42,13 +41,13 @@
 #include <QQuickStyle>
 #include <QQmlContext>
 
-#if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
+#if Qt5AndroidExtras_FOUND
 #include <QAndroidService>
 #endif
 
 #include <memory>
 
-#if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
+#if Qt5AndroidExtras_FOUND
 #include <QAndroidJniObject>
 #include <QtAndroid>
 #endif
@@ -70,22 +69,28 @@ int main(int argc, char *argv[])
     }
 
     qInfo() << "Application starting...";
-#endif
 
+    qputenv("QT_LOGGING_RULES", "org.kde.elisa*=true");
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-
+#endif
     qputenv("QT_GSTREAMER_USE_PLAYBIN_VOLUME", "true");
 
     QApplication app(argc, argv);
 
-#if defined KF5Declarative_FOUND && KF5Declarative_FOUND
+#if defined Q_OS_ANDROID || defined Q_OS_MAC
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif
+
+#if KF5Declarative_FOUND
     KQuickAddons::QtQuickSettings::init();
 #endif
 
     KLocalizedString::setApplicationDomain("elisa");
 
-#if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
+#if Qt5AndroidExtras_FOUND
     qInfo() << QCoreApplication::arguments();
 
     QAndroidJniObject::callStaticMethod<void>("org/kde/elisa/ElisaService",
@@ -94,7 +99,7 @@ int main(int argc, char *argv[])
                                               QtAndroid::androidContext().object());
 #endif
 
-#if defined KF5Crash_FOUND && KF5Crash_FOUND
+#if KF5Crash_FOUND
     KCrash::initialize();
 #endif
 
@@ -108,7 +113,6 @@ int main(int argc, char *argv[])
                           i18n("(c) 2015-2020, Elisa contributors"));
 
     aboutData.addAuthor(QStringLiteral("Matthieu Gallien"),i18n("Creator"), QStringLiteral("mgallien@mgallien.fr"));
-    aboutData.addAuthor(QStringLiteral("Alexander Stippich"), i18n("Author"), QStringLiteral("a.stippich@gmx.net"));
     aboutData.addAuthor(QStringLiteral("Nate Graham"), i18n("Author"), QStringLiteral("nate@kde.org"));
 
     aboutData.addCredit(QStringLiteral("Andrew Lake"), i18n("Concept and design work"), QStringLiteral("jamboarder@gmail.com"));
@@ -124,14 +128,18 @@ int main(int argc, char *argv[])
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
+#if defined Q_OS_ANDROID
+    QQuickStyle::setStyle(QStringLiteral("Material"));
+#else
     QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     QQuickStyle::setFallbackStyle(QStringLiteral("Fusion"));
+#endif
 
     QQmlApplicationEngine engine;
     engine.addImportPath(QStringLiteral("qrc:/imports"));
     QQmlFileSelector selector(&engine);
 
-#if defined KF5Declarative_FOUND && KF5Declarative_FOUND
+#if KF5Declarative_FOUND
     KDeclarative::KDeclarative decl;
     decl.setDeclarativeEngine(&engine);
     decl.setupEngine(&engine);
@@ -140,26 +148,12 @@ int main(int argc, char *argv[])
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
-    auto arguments = DataTypes::EntryDataList{};
-    auto realArgumentsList = parser.positionalArguments();
-
-    for (const auto &oneArgument : realArgumentsList) {
-        arguments.push_back(DataTypes::EntryData{{{DataTypes::ElementTypeRole, ElisaUtils::FileName},
-                                                  {DataTypes::ResourceRole, QUrl::fromUserInput(oneArgument)}}, {}, {}});
+    QList<QUrl> urls;
+    for (const auto &oneArgument : parser.positionalArguments()) {
+        urls.push_back(QUrl::fromUserInput(oneArgument));
     }
 
-    int typeId = qmlRegisterSingletonType<ElisaArguments>("org.kde.elisa.host", 1, 0, "ElisaArguments", [](QQmlEngine *qmlEngine, QJSEngine *scriptEngine) -> QObject* {
-        Q_UNUSED(qmlEngine)
-        Q_UNUSED(scriptEngine)
-
-        auto *result = new ElisaArguments;
-
-        return result;
-    });
-
-    auto *argumentsSingleton = engine.singletonInstance<ElisaArguments*>(typeId);
-
-    argumentsSingleton->setArguments(arguments);
+    engine.rootContext()->setContextProperty(QStringLiteral("elisaStartupArguments"), QVariant::fromValue(urls));
 
     engine.load(QUrl(QStringLiteral("qrc:/qml/ElisaMainWindow.qml")));
 
