@@ -156,7 +156,7 @@ QModelIndex MediaPlayListProxyModel::parent(const QModelIndex &child) const
 
 bool MediaPlayListProxyModel::hasChildren(const QModelIndex &parent) const
 {
-    return (!parent.isValid()) ? false : (rowCount() > 0);
+    return (parent.isValid()) ? false : (rowCount() > 0);
 }
 
 void MediaPlayListProxyModel::setPlayListModel(MediaPlayList *playListModel)
@@ -735,13 +735,8 @@ void MediaPlayListProxyModel::loadPlayListLoaded()
 
     auto newTracks = DataTypes::EntryDataList{};
     for (int i = 0; i < d->mLoadPlaylist.mediaCount(); ++i) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         newTracks.push_back({{{{DataTypes::ElementTypeRole, ElisaUtils::FileName},
                                {DataTypes::ResourceRole, d->mLoadPlaylist.media(i).request().url()}}}, {}, {}});
-#else
-        newTracks.push_back({{{{DataTypes::ElementTypeRole, ElisaUtils::FileName},
-                               {DataTypes::ResourceRole, d->mLoadPlaylist.media(i).canonicalUrl()}}}, {}, {}});
-#endif
     }
 
     enqueue(newTracks, ElisaUtils::ReplacePlayList, ElisaUtils::DoNotTriggerPlay);
