@@ -9,6 +9,8 @@
 
 #include "elisaLib_export.h"
 
+#include "config-upnp-qt.h"
+
 #include "elisautils.h"
 #include "datatypes.h"
 
@@ -115,8 +117,6 @@ Q_SIGNALS:
 
     void openListView(ViewConfigurationData *configurationData);
 
-    void switchFilesBrowserView(int expectedDepth, const QString &mainTitle, const QUrl &imageUrl);
-
     void switchContextView(int expectedDepth, const QString &mainTitle, const QUrl &imageUrl);
 
     void popOneView();
